@@ -22,12 +22,12 @@ import (
 	"github.com/prometheus/client_golang/prometheus"
 	"github.com/prometheus/client_golang/prometheus/promhttp"
 
-	"git.sr.ht/~emersion/soju"
-	"git.sr.ht/~emersion/soju/auth"
-	"git.sr.ht/~emersion/soju/config"
-	"git.sr.ht/~emersion/soju/database"
-	"git.sr.ht/~emersion/soju/fileupload"
-	"git.sr.ht/~emersion/soju/identd"
+	"codeberg.org/emersion/soju"
+	"codeberg.org/emersion/soju/auth"
+	"codeberg.org/emersion/soju/config"
+	"codeberg.org/emersion/soju/database"
+	"codeberg.org/emersion/soju/fileupload"
+	"codeberg.org/emersion/soju/identd"
 )
 
 // TCP keep-alive interval for downstream TCP connections
@@ -223,6 +223,9 @@ func main() {
 				log.Fatalf("failed to start listener on %q: %v", listen, err)
 			}
 			ln = proxyProtoListener(ln, srv)
+			if err := os.Chmod(u.Path, 0775); err != nil {
+				log.Printf("failed to chmod Unix IRC socket: %v", err)
+			}
 			go func() {
 				if err := srv.Serve(ln, srv.Handle); err != nil {
 					log.Printf("serving %q: %v", listen, err)
@@ -276,6 +279,9 @@ func main() {
 			if err != nil {
 				log.Fatalf("failed to start listener on %q: %v", listen, err)
 			}
+			if err := os.Chmod(u.Path, 0775); err != nil {
+				log.Printf("failed to chmod Unix WS socket: %v", err)
+			}
 			go func() {
 				if err := http.Serve(ln, srv); err != nil {
 					log.Fatalf("serving %q: %v", listen, err)
@@ -377,6 +383,9 @@ func main() {
 			if err != nil {
 				log.Fatalf("failed to start listener on %q: %v", listen, err)
 			}
+			if err := os.Chmod(u.Path, 0775); err != nil {
+				log.Printf("failed to chmod Unix HTTP socket: %v", err)
+			}
 			go func() {
 				if err := http.Serve(ln, httpMux); err != nil {
 					log.Fatalf("serving %q: %v", listen, err)
