@@ -17,10 +17,10 @@ import (
 	"github.com/emersion/go-sasl"
 	"gopkg.in/irc.v4"
 
-	"git.sr.ht/~emersion/soju/auth"
-	"git.sr.ht/~emersion/soju/database"
-	"git.sr.ht/~emersion/soju/msgstore"
-	"git.sr.ht/~emersion/soju/xirc"
+	"codeberg.org/emersion/soju/auth"
+	"codeberg.org/emersion/soju/database"
+	"codeberg.org/emersion/soju/msgstore"
+	"codeberg.org/emersion/soju/xirc"
 )
 
 type ircError struct {
@@ -328,7 +328,7 @@ func serverSASLMechanisms(srv *Server) []string {
 }
 
 type downstreamConn struct {
-	conn
+	*conn
 
 	id uint64
 
@@ -363,7 +363,7 @@ func newDownstreamConn(srv *Server, ic ircConn, id uint64) *downstreamConn {
 	options := connOptions{Logger: logger}
 	cm := xirc.CaseMappingASCII
 	dc := &downstreamConn{
-		conn:         *newConn(srv, ic, &options),
+		conn:         newConn(srv, ic, &options),
 		id:           id,
 		nick:         "*",
 		nickCM:       "*",
@@ -2142,7 +2142,6 @@ func (dc *downstreamConn) handleMessageRegistered(ctx context.Context, msg *irc.
 		// Clients will use the first mask to match RPL_ENDOFWHO
 		endOfWhoToken := msg.Params[0]
 
-		// TODO: add support for WHOX mask2
 		mask := msg.Params[0]
 		var options string
 		if len(msg.Params) > 1 {
@@ -2154,8 +2153,10 @@ func (dc *downstreamConn) handleMessageRegistered(ctx context.Context, msg *irc.
 		// TODO: support mixed bouncer/upstream WHO queries
 		maskCM := dc.casemap(mask)
 		if dc.network == nil && maskCM == dc.nickCM {
-			// TODO: support AWAY (H/G) in self WHO reply
 			flags := "H"
+			if dc.away != nil {
+				flags = "G"
+			}
 			if dc.user.Admin {
 				flags += "*"
 			}
@@ -2230,6 +2231,23 @@ func (dc *downstreamConn) handleMessageRegistered(ctx context.Context, msg *irc.
 				}
 				if uc.isChannel(mask) {
 					info.Channel = mask
+
+					// Set channel membership prefixes from cached NAMES reply
+					ch := uc.channels.Get(info.Channel)
+					memberships := ch.Members.Get(info.Nickname)
+					prefixes := formatMemberPrefix(*memberships, dc)
+
+					// Channel membership prefixes are listed after away status ('G'/'H')
+					// and optional server operator indicator ('*')
+					i := strings.IndexFunc(info.Flags, func(f rune) bool {
+						return f != 'G' && f != 'H' && f != '*'
+					})
+
+					if i == -1 {
+						info.Flags += prefixes
+					} else {
+						info.Flags = info.Flags[:i] + prefixes + info.Flags[i:]
+					}
 				}
 				dc.SendMessage(ctx, xirc.GenerateWHOXReply(fields, &info))
 			}
